/***
*
*	Open-Source Jailbreak for Half-Life
*	Distributed under the Open-Source Mod License (see license.txt)
*
*	Contributors to this file:
*		jIMMy_b
*
****
*
*	Copyright (c) 1999, Valve LLC. All rights reserved.
*	
*	This product contains software technology licensed from Id 
*	Software, Inc. ("Id Technology").  Id Technology (c) 1996 Id Software, Inc. 
*	All Rights Reserved.
*
*   Use, distribution, and modification of this source code and/or resulting
*   object code is restricted to non-commercial enhancements to products from
*   Valve LLC.  All other use, distribution, or modification is prohibited
*   without written permission from Valve LLC.
*
****/


#include	"extdll.h"
#include	"util.h"
#include	"cbase.h"
#include	"player.h"
#include	"weapons.h"
#include	"gamerules.h"
#include	"jb_gamerules.h"
#include	"game.h"



//===================================================================
// CreateRadar: read positions and properties of trigger_radar
// entities from a separate file
//===================================================================
void CJailBreakTeamplay::CreateRadar()
{
	char RadarFileName[256], *RadarFile;
	int nLength;
	
	world_left = world_right = world_top = world_bottom = spr_left = spr_right = spr_top = spr_bottom = 0;
	
	sprintf( RadarFileName, "maps/%s.rdr", STRING( gpGlobals->mapname ) );
	
	RadarFile = (char *)LOAD_FILE_FOR_ME(RadarFileName, &nLength);
	
	if( !nLength || !RadarFile )
		return;
	
	sscanf( RadarFile, "%i %i %i %i %i %i %i %i", &world_left, &world_right,
		&world_top, &world_bottom, &spr_left, &spr_right, &spr_top, &spr_bottom );
	
	FREE_FILE( RadarFile );
}


void CJailBreakTeamplay::UpdateRadar(void)
{
	int i, j, numplrs;
	
	if( gpGlobals->time > m_fRefreshRadarTime )
	{
		m_fRefreshRadarTime = gpGlobals->time + 0.2;
		
		for( i=1; i <= gpGlobals->maxClients; i++ )
		{
			CBasePlayer *plr = (CBasePlayer *)UTIL_PlayerByIndex( i );
			
			if( !plr || !plr->IsNetClient() || !plr->IsAlive() )
				continue;
			if( !plr->world_right-plr->world_left || !plr->world_top-plr->world_bottom )
				return;

			double x, y;
			
			x  = fabs(plr->pev->origin.x - plr->world_left) / fabs(plr->world_right-plr->world_left);
			y  = fabs(plr->pev->origin.y - plr->world_top) / fabs(plr->world_top-plr->world_bottom);
			x *= fabs(plr->spr_right - plr->spr_left);
			y *= fabs(plr->spr_bottom - plr->spr_top);
			x += plr->spr_left;
			y += plr->spr_top;
			plr->out_x = fabs(x);
			plr->out_y = fabs(y);
		}

		for( i=1; i <= gpGlobals->maxClients; i++ )
		{
			CBasePlayer *msgtarg = (CBasePlayer *)UTIL_PlayerByIndex( i );
			if( msgtarg && msgtarg->IsNetClient() ) {
				numplrs = 0;
				for( j=1; j<=gpGlobals->maxClients; j++ ) {
					if( RadarVisible( (CBasePlayer *)UTIL_PlayerByIndex(j), msgtarg ) )
						numplrs++;
				}
				MESSAGE_BEGIN( MSG_ONE_UNRELIABLE, gmsgRadar, NULL, msgtarg->pev);
				WRITE_BYTE( numplrs );
				for( int j=1; j <= gpGlobals->maxClients; j++ )
				{
					CBasePlayer *plr = (CBasePlayer *)UTIL_PlayerByIndex( j );
					if( RadarVisible( plr, msgtarg ) )
					{
						WRITE_BYTE( (msgtarg==plr)?(0x06):(0x07) );	// Dot color: either cyan (if this is current player), or white
						WRITE_BYTE( (BYTE)plr->out_x );
						WRITE_BYTE( (BYTE)plr->out_y );
					}
				}
				MESSAGE_END();
			}
		}
	}
}


int CJailBreakTeamplay::RadarVisible( CBasePlayer *seen, CBasePlayer *seeing )
{
	if( !seen )
		return 0;
	if( !seen->IsNetClient() )
		return 0;
	if( seen->m_nTeam < 0 )
		return 0;
	if( !seen->world_right && !seen->world_bottom )
		return 0;
	
	if( seeing )
	{
		if( PlayerRelationship( seeing, seen ) == GR_TEAMMATE )
			return 1;
		else
			return 0;
	}
	else
	{
		return 1;
	}
}